#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <signal.h>
#include <syslog.h>
#include <string.h>
#include "board_resource.h"

BR_HANDLE wdt_fd = 0;
int disableWDT()
{
	BR_RESULT ret = BR_SUCCESS;
	ret = WDT_Init(&wdt_fd);
	if (ret != BR_SUCCESS)
	{
		printf("open device fail[%d]\n", ret);
		return 0;
	}
	ret = WDT_Disable(wdt_fd);
	if (ret != BR_SUCCESS)
	{
		printf("disable wdt fail[%d]\n", ret);
		return 0;
	}
	WDT_DeInit(wdt_fd);
	return 0;
}
int enableeWDT(int second)
{
	BR_RESULT ret = BR_SUCCESS;
	ret = WDT_Init(&wdt_fd);
	if (ret != BR_SUCCESS)
	{
		printf("open device fail[%d]\n", ret);
		return 0;
	}
	ret = WDT_Enable(wdt_fd,second);
	if (ret != BR_SUCCESS)
	{
		printf("disable wdt fail[%d]\n", ret);
		return 0;
	}
	while (second)
	{
		printf("\r%02d",second--);
		fflush(stdout);
		sleep(1);
	}
	return 0;
}

int feedWDT()
{
	printf("Press Ctrl+c to stop strobe watchdog \nthe system will reboot in 10 seconds\n");
	BR_RESULT ret = BR_SUCCESS;
	ret = WDT_Init(&wdt_fd);
	if (ret != BR_SUCCESS)
	{
		printf("open device fail[%d]\n", ret);
		return 0;
	}
	ret = WDT_Enable(wdt_fd,10);
	if (ret != BR_SUCCESS)
	{
		printf("enable wdt fail[%d]\n", ret);
		return 0;
	}

	WDT_SetMode(wdt_fd,WATCH_MODE_MANUAL,130);
	while(1){
		ret = WDT_Strobe(wdt_fd);
		if (ret != BR_SUCCESS)
		{
			printf("strobe wdt fail[%d]\n", ret);
			if(BR_DEVICE_ALREADY_OPENED == ret)
			{
				do
				{
					ret = WDT_Enable(wdt_fd,2);
					if (ret != BR_SUCCESS)
					{
						printf("enable wdt fail[%d]\n", ret);
					}else{
						printf("enable wdt success\n");
					}
				}while(ret != BR_SUCCESS);
			}
		}else{
			printf("strobe wdt success\n");
		}
		sleep(1);
	}
	return 0;
}

void showUsage()
{
	printf("Usage:\n");
	printf("\t wdttest -d     disable wdt\n");
	printf("\t wdttest -e 10     enable wdt and reboot in 10 seconds\n");
	printf("\t wdttest -t     test wdt feed\n");
	return;
}

int main(int argc, char *argv[])
{

	if(argc < 2)
	{
		showUsage();
		return -1;
	}

	if(!strcmp(argv[1],"-d"))
	{
		disableWDT();
	}else  if(!strcmp(argv[1],"-t"))
	{
		feedWDT();
	}else  if(!strcmp(argv[1],"-e"))
	{
		if(argc < 3)
		{
			showUsage();
			return -1;
		}
		int second = strtoul(argv[2],NULL,0);
		enableeWDT(second);
	}

	return 0;
}
